IndexOutOfBoundsException class
Thrown when an index or axis is out of valid range.
- Inheritance
-
- Object
- TensorException
- IndexOutOfBoundsException
Constructors
- IndexOutOfBoundsException({required int index, required int min, required int max, String? dimension})
- Creates an index out of bounds exception.
Properties
- dimension → String?
-
The dimension name (e.g., 'axis', 'dim').
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
The invalid index value.
final
- max → int
-
The maximum valid value (inclusive).
final
- message → String
-
The error message.
finalinherited
- min → int
-
The minimum valid value (inclusive).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited