MishOp class
Mish activation function.
Self-regularizing non-monotonic activation used in YOLOv4+.
Equivalent to F.mish() in PyTorch.
Formula
mish(x) = x * tanh(softplus(x)) = x * tanh(ln(1 + exp(x)))
final result = MishOp()(tensor);
- Inheritance
-
- Object
- TransformOp
- MishOp
- Mixed-in types
Constructors
- MishOp()
- Creates a Mish operation.
Properties
- capabilities → OperationCapabilities
-
The capabilities of this operation.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The human-readable name of this operation.
no setteroverride
- requiresContiguous → bool
-
Whether this operation requires contiguous input.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
TensorBuffer input) → TensorBuffer -
Applies this transform to
inputand returns the result.override -
applyInPlace(
TensorBuffer input) → void -
Applies this transform to
inputin place.override -
call(
TensorBuffer input) → TensorBuffer -
Alias for apply.
inherited
-
cloneForModification(
TensorBuffer input) → TensorBuffer -
Creates an output buffer from input, ensuring contiguity with single copy.
inherited
-
computeOutputShape(
List< int> inputShape) → List<int> -
Computes the output shape for a given
inputShape.override -
ensureContiguous(
TensorBuffer input) → TensorBuffer -
Returns a contiguous version of
inputif needed.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited