SinOp class
Computes the sine of each element (in radians).
Equivalent to torch.sin() in PyTorch and the ONNX Sin operator.
final result = SinOp()(tensor); // sin(tensor)
- Inheritance
-
- Object
- TransformOp
- UnaryMathOp
- SinOp
Constructors
- SinOp()
- Creates a sine operation.
Properties
- capabilities → OperationCapabilities
-
The capabilities of this operation.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The human-readable name of this operation.
no setteroverride
- requiresContiguous → bool
-
Whether this operation requires contiguous input.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
TensorBuffer input) → TensorBuffer -
Applies this transform to
inputand returns the result.inherited -
applyInPlace(
TensorBuffer input) → void -
Applies this transform to
inputin place.inherited -
call(
TensorBuffer input) → TensorBuffer -
Alias for apply.
inherited
-
cloneForModification(
TensorBuffer input) → TensorBuffer -
Creates an output buffer from input, ensuring contiguity with single copy.
inherited
-
computeOutputShape(
List< int> inputShape) → List<int> -
Computes the output shape for a given
inputShape.inherited -
ensureContiguous(
TensorBuffer input) → TensorBuffer -
Returns a contiguous version of
inputif needed.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
operation(
double value) → double -
Applies the mathematical function to a single value.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited